@@ -1,12 +1,4 @@
-from __future__ import absolute_import, unicode_literals
-
-import sys
-
-if sys.version_info > (3,):
-    from shutil import which
-else:
-    from distutils.spawn import find_executable as which
-
+from shutil import which
 
 from virtualenv.activation import NushellActivator
 from virtualenv.info import IS_WIN
@@ -19,11 +11,11 @@ def test_nushell(activation_tester_class, activation_tester):
             if cmd is None and IS_WIN:
                 cmd = "c:\\program files\\nu\\bin\\nu.exe"
 
-            super(Nushell, self).__init__(NushellActivator, session, cmd, "activate.nu", "nu")
+            super().__init__(NushellActivator, session, cmd, "activate.nu", "nu")
 
             self.unix_line_ending = not IS_WIN
 
         def print_prompt(self):
-            return r"echo $virtual_prompt; printf '\n'"
+            return r"$env.VIRTUAL_PROMPT"
 
     activation_tester(Nushell)
